@@ -31,12 +31,10 @@ abstract class DuskTestCase extends BaseTestCase
             $this->shouldStartMaximized() ? '--start-maximized' : '--window-size=1920,1080',
             '--disable-search-engine-choice-screen',
             '--disable-smooth-scrolling',
-        ])->unless($this->hasHeadlessDisabled(), function (Collection $items) {
-            return $items->merge([
-                '--disable-gpu',
-                '--headless=new',
-            ]);
-        })->all());
+        ])->unless($this->hasHeadlessDisabled(), fn (Collection $items) => $items->merge([
+            '--disable-gpu',
+            '--headless=new',
+        ]))->all());
 
         return RemoteWebDriver::create(
             $_ENV['DUSK_DRIVER_URL'] ?? $_ENV['DUSK_DRIVER_URL'] ?? 'http://localhost:9515',
